@@ -34,8 +34,6 @@ add_difference <- function(x, ...) {
 #' @param estimate_fun ([`formula-list-selector`][syntax])\cr
 #'   List of formulas specifying the functions
 #'   to round and format differences and confidence limits.
-#'   Default is
-#'   `list(c(all_continuous(), all_categorical(FALSE)) ~ label_style_sigfig(), all_categorical() ~ \(x) paste0(style_sigfig(x, scale = 100), "%"))`
 #' @param conf.level (`numeric`)\cr
 #'   a scalar in the interval `(0, 1)` indicating the confidence level. Default is 0.95
 #' @inheritParams  add_p.tbl_summary
@@ -81,7 +79,7 @@ add_difference.tbl_summary <- function(x,
                                        pvalue_fun = label_style_pvalue(digits = 1),
                                        estimate_fun = list(
                                          c(all_continuous(), all_categorical(FALSE)) ~ label_style_sigfig(),
-                                         all_dichotomous() ~ function(x) ifelse(is.na(x), NA_character_, paste0(style_sigfig(x, scale = 100), "%")),
+                                         all_dichotomous() ~ label_style_sigfig(scale = 100, suffix = "%"),
                                          all_tests("smd") ~ label_style_sigfig()
                                        ),
                                        ...) {
