@@ -56,7 +56,7 @@ add_p <- function(x, ...) {
 #' @section test argument:
 #'
 #' See the [?tests][tests] help file for details on available tests and creating custom tests.
-#' The [?tests][tests] help file also includes psuedo-code for each test to be clear
+#' The [?tests][tests] help file also includes pseudo-code for each test to be clear
 #' precisely how the calculation is performed.
 #'
 #' The default test used in `add_p()` primarily depends on these factors:
@@ -248,7 +248,7 @@ calculate_and_add_test_results <- function(x, include, group = NULL, test.args,
                 variable = variable,
                 by = x$inputs$by,
                 group = group,
-                type = x$inputs$type[[variable]],
+                type = tryCatch(x$inputs$type[[variable]], error = \(e) NULL), # in tbl_survfit(), the type argument is for transforming the estimate, not the summary type
                 test.args = test.args[[variable]],
                 adj.vars = adj.vars,
                 conf.level = conf.level,
