@@ -1,36 +1,30 @@
-#' Modify Hidden Columns
+#' Modify hidden columns
 #'
-#' \lifecycle{maturing}
 #' Use these functions to hide or unhide columns in a gtsummary table.
+#' Use `show_header_names(show_hidden=TRUE)` to print available columns to update.
 #'
 #' @inheritParams modify_table_styling
 #'
 #' @name modify_column_hide
-#' @family Advanced modifiers
+#' @author Daniel D. Sjoberg
+#'
 #' @examples
-#' \donttest{
 #' # Example 1 ----------------------------------
 #' # hide 95% CI, and replace with standard error
-#' modify_column_hide_ex1 <-
-#'   lm(age ~ marker + grade, trial) %>%
-#'   tbl_regression() %>%
-#'   modify_column_hide(columns = ci) %>%
+#' lm(age ~ marker + grade, trial) |>
+#'   tbl_regression() |>
+#'   modify_column_hide(conf.low) |>
 #'   modify_column_unhide(columns = std.error)
-#' }
-#' @section Example Output:
-#' \if{html}{Example 1}
-#'
-#' \if{html}{\out{
-#' `r man_create_image_tag(file = "modify_column_hide_ex1.png", width = "45")`
-#' }}
 NULL
 
 #' @rdname modify_column_hide
-#' @seealso Review [list, formula, and selector syntax][syntax] used throughout gtsummary
 #' @export
 modify_column_hide <- function(x, columns) {
-  .assert_class(x, "gtsummary")
+  set_cli_abort_call()
+  check_class(x, "gtsummary")
   updated_call_list <- c(x$call_list, list(modify_column_hide = match.call()))
+
+  # hide columns ---------------------------------------------------------------
   x <-
     modify_table_styling(
       x = x,
@@ -38,6 +32,7 @@ modify_column_hide <- function(x, columns) {
       hide = TRUE
     )
 
+  # return updated object ------------------------------------------------------
   x$call_list <- updated_call_list
   x
 }
@@ -45,8 +40,11 @@ modify_column_hide <- function(x, columns) {
 #' @rdname modify_column_hide
 #' @export
 modify_column_unhide <- function(x, columns) {
-  .assert_class(x, "gtsummary")
+  set_cli_abort_call()
+  check_class(x, "gtsummary")
   updated_call_list <- c(x$call_list, list(modify_column_unhide = match.call()))
+
+  # unhide columns -------------------------------------------------------------
   x <-
     modify_table_styling(
       x = x,
@@ -54,6 +52,7 @@ modify_column_unhide <- function(x, columns) {
       hide = FALSE
     )
 
+  # return updated object ------------------------------------------------------
   x$call_list <- updated_call_list
   x
 }
