@@ -426,7 +426,12 @@ tbl_summary <- function(data,
   x
 }
 
-.add_gts_column_to_cards_summary <- function(cards, variables, by) {
+.add_gts_column_to_cards_summary <- function(cards, variables, by, hierarchical = FALSE) {
+  if ("gts_column" %in% names(cards)) {
+    cli::cli_inform("The {.val gts_column} column is alread present. Defining the column has been skipped.")
+    return(cards)
+  }
+
   # adding the name of the column the stats will populate
   if (is_empty(by)) {
     cards$gts_column <-
@@ -435,6 +440,16 @@ tbl_summary <- function(data,
         "stat_0",
         NA_character_
       )
+  } else if (hierarchical) { # disregard hierarchies, only check by variable
+    cards <- cards |>
+      dplyr::group_by(.data$group1_level) |>
+      dplyr::mutate(gts_column = paste0("stat_", dplyr::cur_group_id()))
+
+    # process overall row
+    cards[cards$variable %in% by, ] <- cards[cards$variable %in% by, ] |>
+      dplyr::group_by(.data$variable_level) |>
+      dplyr::mutate(gts_column = paste0("stat_", dplyr::cur_group_id())) |>
+      dplyr::ungroup()
   } else {
     # styler: off
     cards <-
@@ -468,7 +483,7 @@ tbl_summary <- function(data,
 
   obs_to_drop <- is.na(data[[by]])
   cli::cli_inform("{.val {sum(obs_to_drop)}} missing rows in the {.val {by}} column have been removed.")
-  data[!obs_to_drop, ]
+  dplyr::filter(data, !obs_to_drop)
 }
 
 .check_stats_available <- function(cards, statistic) {
