@@ -53,8 +53,8 @@ test_that("add_ci(method) with no `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilcox.test results
@@ -70,8 +70,8 @@ test_that("add_ci(method) with no `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilson
@@ -87,8 +87,8 @@ test_that("add_ci(method) with no `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilson.no.correct
@@ -104,8 +104,8 @@ test_that("add_ci(method) with no `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wald
@@ -121,8 +121,8 @@ test_that("add_ci(method) with no `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wald.no.correct
@@ -138,8 +138,8 @@ test_that("add_ci(method) with no `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check exact
@@ -155,8 +155,8 @@ test_that("add_ci(method) with no `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check agresti.coull
@@ -172,8 +172,8 @@ test_that("add_ci(method) with no `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check jeffreys
@@ -189,8 +189,8 @@ test_that("add_ci(method) with no `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 })
 
@@ -247,8 +247,8 @@ test_that("add_ci(method) with `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilcox.test results
@@ -265,8 +265,8 @@ test_that("add_ci(method) with `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilson
@@ -283,8 +283,8 @@ test_that("add_ci(method) with `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilson.no.correct
@@ -301,8 +301,8 @@ test_that("add_ci(method) with `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check exact
@@ -319,8 +319,8 @@ test_that("add_ci(method) with `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check agresti.coull
@@ -337,8 +337,8 @@ test_that("add_ci(method) with `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check jeffreys
@@ -355,8 +355,8 @@ test_that("add_ci(method) with `by`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 })
 
@@ -413,8 +413,8 @@ test_that("add_ci(method) after `add_overall()`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilcox.test results
@@ -430,8 +430,8 @@ test_that("add_ci(method) after `add_overall()`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilson
@@ -447,8 +447,8 @@ test_that("add_ci(method) after `add_overall()`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilson.no.correct
@@ -464,8 +464,8 @@ test_that("add_ci(method) after `add_overall()`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check exact
@@ -481,8 +481,8 @@ test_that("add_ci(method) after `add_overall()`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check agresti.coull
@@ -498,8 +498,8 @@ test_that("add_ci(method) after `add_overall()`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check jeffreys
@@ -515,8 +515,8 @@ test_that("add_ci(method) after `add_overall()`", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 })
 
@@ -613,8 +613,8 @@ test_that("add_ci(conf.level)", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilcox.test results
@@ -630,8 +630,8 @@ test_that("add_ci(conf.level)", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilson
@@ -647,8 +647,8 @@ test_that("add_ci(conf.level)", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check wilson.no.correct
@@ -664,8 +664,8 @@ test_that("add_ci(conf.level)", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check exact
@@ -681,8 +681,8 @@ test_that("add_ci(conf.level)", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check agresti.coull
@@ -698,8 +698,8 @@ test_that("add_ci(conf.level)", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 
   # check jeffreys
@@ -715,8 +715,8 @@ test_that("add_ci(conf.level)", {
         )
       ) |>
       cards::apply_fmt_fn() |>
-      cards::get_ard_statistics(.column = "stat_fmt") %>%
-      {glue("{conf.low}, {conf.high}", .envir = .)} # styler: off
+      cards::get_ard_statistics(.column = "stat_fmt") |>
+      glue_data("{conf.low}, {conf.high}")
   )
 })
 
@@ -800,3 +800,16 @@ test_that("add_ci() correctly handles dichotomous variables", {
     tbl$cards$add_ci[c("variable", "variable_level")] |> unique() |> deframe()
   )
 })
+
+test_that("add_ci() messaging for tbl_summary(percent)", {
+  expect_message(
+    trial |>
+      tbl_summary(
+        missing = "no",
+        statistic = all_continuous() ~ "{mean} ({sd})",
+        include = c(marker, response, trt), percent = "row"
+      ) |>
+      add_ci(),
+    "function is meant to work with"
+  )
+})
