@@ -1,3 +1,6 @@
+skip_on_cran()
+skip_if_not(is_pkg_installed(c("cardx", "broom"), reference_pkg = "gtsummary"))
+
 test_that("sort_p() works", {
   # check the variables sort to the correct order
   expect_equal(
